@@ -775,19 +775,35 @@ def pbdDict_bxReposRoot(
         """ repoName of remGitRepoPath, is same as basename of dstPathRel"""
         pathComps = os.path.split(dstPathRel)
         baseDir = pathComps[0]
-        #repoName = pathComps[1]
+        # repoName = pathComps[1]
         if vcMode == "anon":
             # git clone git://github.com/SomeUser/SomeRepo.git
             #               "cd {root}/{baseDir} && git clone git@github.com:{gitRepoPath}.git"
-            command(  dstPathRel,
-              "cd {root}/{baseDir} && git clone git://github.com/{gitRepoPath}.git"
-              .format(root=root, baseDir=baseDir, gitRepoPath=gitRepoPath)
+            command(
+                dstPathRel,
+                "cd {root}/{baseDir} && git clone git://github.com/{gitRepoPath}.git"
+                .format(
+                    root=root,
+                    baseDir=baseDir,
+                    gitRepoPath=gitRepoPath,
+                )
             )
         elif vcMode == "auth":
-            command(  dstPathRel,
-              "cd {root}/{baseDir} && git clone https://{gitUserName}:{gitPasswd}@github.com/{gitRepoPath}"
-              .format(root=root, baseDir=baseDir, gitUserName=gitUserName, gitPasswd=gitPasswd, gitRepoPath=gitRepoPath)
+            # command(  dstPathRel,
+            #   "cd {root}/{baseDir} && git clone https://{gitUserName}:{gitPasswd}@github.com/{gitRepoPath}"
+            #   .format(root=root, baseDir=baseDir, gitUserName=gitUserName, gitPasswd=gitPasswd, gitRepoPath=gitRepoPath)
+            # )
+            command(
+                dstPathRel,
+                "cd {root}/{baseDir} && git clone git@github.com:{gitRepoPath}.git"
+                .format(
+                    root=root,
+                    baseDir=baseDir,
+                    gitRepoPath=gitRepoPath,
+                )
             )
+   
+            
         else:
             icm.EH_problem_usageError("")
 
@@ -810,26 +826,41 @@ def pbdDict_bxReposRoot(
             # Note: Strange: You can not use multiple command() below.
             # Not understood yet. To be revisited. MB-20200625
             #
-            command(  locPathRel,
-                      "cd {locDirnameFull} && git clone git://github.com/{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
-                      .format(locDirnameFull=locDirnameFull, remGitRepoPath=remGitRepoPath, repoName=repoName, locBasenameRel=locBasenameRel)
+            command(
+                locPathRel,
+                "cd {locDirnameFull} && git clone git://github.com/{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
+                .format(
+                    locDirnameFull=locDirnameFull,
+                    remGitRepoPath=remGitRepoPath,
+                    repoName=repoName,
+                    locBasenameRel=locBasenameRel,
+                )
             )
             
         elif vcMode == "auth":
             #
-            # Note: Strange: You can not use multiple command() below.
-            # Not understood yet. To be revisited. MB-20200625
+            # Note: You can not use multiple command() below.
+            # The last command's info gets appended to a list and it is onth that which is executed.
             #
-            command(  locDirnamePlusRepoRel,
-              "cd {locDirnameFull} && git clone https://{gitUserName}:{gitPasswd}@github.com/{remGitRepoPath} && mv {repoName} {locBasenameRel}"
-              .format(
-                  locDirnameFull=locDirnameFull,
-                  gitUserName=gitUserName,
-                  gitPasswd=gitPasswd,
-                  remGitRepoPath=remGitRepoPath,
-                  repoName=repoName,
-                  locBasenameRel=locBasenameRel
-              )
+            # command(  locDirnamePlusRepoRel,
+            #   "cd {locDirnameFull} && git clone https://{gitUserName}:{gitPasswd}@github.com/{remGitRepoPath} && mv {repoName} {locBasenameRel}"
+            #   .format(
+            #       locDirnameFull=locDirnameFull,
+            #       gitUserName=gitUserName,
+            #       gitPasswd=gitPasswd,
+            #       remGitRepoPath=remGitRepoPath,
+            #       repoName=repoName,
+            #       locBasenameRel=locBasenameRel
+            #   )
+            # )
+            command(locPathRel,
+                    "cd {locDirnameFull} && git clone git@github.com:{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
+                    .format(
+                        locDirnameFull=locDirnameFull,
+                        remGitRepoPath=remGitRepoPath,
+                        repoName=repoName,
+                        locBasenameRel=locBasenameRel
+                    )
             )
             
         else:
@@ -1076,20 +1107,34 @@ def pbdDict_extRepos(
             command(
                 dstPathRel,
                 "cd {root}/{baseDir} && git clone git://github.com/{gitRepoPath}.git"
-                .format(root=root, baseDir=baseDir, gitRepoPath=gitRepoPath)
+                .format(
+                    root=root,
+                    baseDir=baseDir,
+                    gitRepoPath=gitRepoPath,
+                )
             )
         elif vcMode == "auth":
-            command(  dstPathRel,
-              "cd {root}/{baseDir} && git clone https://{gitUserName}:{gitPasswd}@github.com/{gitRepoPath}"
-              .format(root=root, baseDir=baseDir, gitUserName=gitUserName, gitPasswd=gitPasswd, gitRepoPath=gitRepoPath)
+            # command(  dstPathRel,
+            #   "cd {root}/{baseDir} && git clone https://{gitUserName}:{gitPasswd}@github.com/{gitRepoPath}"
+            #   .format(root=root, baseDir=baseDir, gitUserName=gitUserName, gitPasswd=gitPasswd, gitRepoPath=gitRepoPath)
+            # )
+            command(
+                dstPathRel,
+                "cd {root}/{baseDir} && git clone git@github.com:{gitRepoPath}.git"
+                .format(
+                    root=root,
+                    baseDir=baseDir,
+                    gitRepoPath=gitRepoPath,
+                )
             )
+ 
         else:
             icm.EH_problem_usageError("")
 
 
     def gitCloneBase(locPathRel, remGitRepoPath, vcMode):
         locBasenameRel = os.path.basename(locPathRel)
-        locDirnameRel =  os.path.dirname(locPathRel)
+        locDirnameRel = os.path.dirname(locPathRel)
         
         locDirnameFull = os.path.join(root, locDirnameRel)
         
@@ -1105,9 +1150,15 @@ def pbdDict_extRepos(
             # Note: Strange: You can not use multiple command() below.
             # Not understood yet. To be revisited. MB-20200625
             #
-            command(  locPathRel,
-                      "cd {locDirnameFull} && git clone git://github.com/{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
-                      .format(locDirnameFull=locDirnameFull, remGitRepoPath=remGitRepoPath, repoName=repoName, locBasenameRel=locBasenameRel)
+            command(
+                locPathRel,
+                "cd {locDirnameFull} && git clone git://github.com/{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
+                .format(
+                    locDirnameFull=locDirnameFull,
+                    remGitRepoPath=remGitRepoPath,
+                    repoName=repoName,
+                    locBasenameRel=locBasenameRel,
+                )
             )
             
         elif vcMode == "auth":
@@ -1115,18 +1166,28 @@ def pbdDict_extRepos(
             # Note: Strange: You can not use multiple command() below.
             # Not understood yet. To be revisited. MB-20200625
             #
-            command(  locDirnamePlusRepoRel,
-              "cd {locDirnameFull} && git clone https://{gitUserName}:{gitPasswd}@github.com/{remGitRepoPath} && mv {repoName} {locBasenameRel}"
-              .format(
-                  locDirnameFull=locDirnameFull,
-                  gitUserName=gitUserName,
-                  gitPasswd=gitPasswd,
-                  remGitRepoPath=remGitRepoPath,
-                  repoName=repoName,
-                  locBasenameRel=locBasenameRel
-              )
+            # command(  locDirnamePlusRepoRel,
+            #   "cd {locDirnameFull} && git clone https://{gitUserName}:{gitPasswd}@github.com/{remGitRepoPath} && mv {repoName} {locBasenameRel}"
+            #   .format(
+            #       locDirnameFull=locDirnameFull,
+            #       gitUserName=gitUserName,
+            #       gitPasswd=gitPasswd,
+            #       remGitRepoPath=remGitRepoPath,
+            #       repoName=repoName,
+            #       locBasenameRel=locBasenameRel
+            #   )
+            # )
+            command(
+                locPathRel,
+                "cd {locDirnameFull} && git clone git@github.com:{remGitRepoPath}.git && mv {repoName} {locBasenameRel}"
+                .format(
+                    locDirnameFull=locDirnameFull,
+                    remGitRepoPath=remGitRepoPath,
+                    repoName=repoName,
+                    locBasenameRel=locBasenameRel,
+                )
             )
-            
+
         else:
             icm.EH_problem_usageError("")
             
