@@ -838,7 +838,22 @@ def pbdDict_bisosRoot(
     directory('apps')
     symLink('apps/bxtex', 'git/bxRepos/bxlcnt/bxtex')
 
+    directory('panels')
+    directory('panels/bisos')
+    directory('panels/blee')
+    directory('panels/bxde')            
+    symLink('panels/bisos/core', 'git/bxRepos/blee-binders/bisos-core')
+    symLink('panels/bisos/dev', 'git/bxRepos/blee-binders/bisos-dev')
+    symLink('panels/bisos/model', 'git/bxRepos/blee-binders/bisos-model')        
+    symLink('panels/blee/core', 'git/bxRepos/blee-binders/blee-core')
+    symLink('panels/blee/dev', 'git/bxRepos/blee-binders/blee-dev')
+    symLink('panels/blee/model', 'git/bxRepos/blee-binders/blee-model')        
+    symLink('panels/bxde/core', 'git/bxRepos/blee-binders/bxde-core')
+    symLink('panels/bxde/dev', 'git/bxRepos/blee-binders/bxde-dev')
+    symLink('panels/bxde/model', 'git/bxRepos/blee-binders/bxde-model')        
+    
     directory('blee')
+    # blee directory is then populated with pbdDict_bleeRoot
 
     return pbdDict
 
